# Citation & Acknowledgements

If you use Krewlyzer in your work, please cite this repository and [cfDNAFE](https://github.com/Cuiwanxin1998/cfDNAFE).

## Primary Literature
Krewlyzer implements or adapts methods from the following papers:

1.  **DELFI (FSR)**: Mouliere F, Chandrananda D, Piskorz AM, et al. Enhanced detection of circulating tumor DNA by fragment size analysis. *Sci Transl Med*. 2018;10(466):eaat4921. [DOI](https://doi.org/10.1126/scitranslmed.aat4921)
2.  **WPS**: Snyder MW, Kircher M, Hill AJ, Daza RM, Shendure J. Cell-free DNA Comprises an In Vivo Nucleosome Footprint that Informs Its Tissues-Of-Origin. *Cell*. 2016;164(1-2):57-68. [DOI](https://doi.org/10.1016/j.cell.2015.11.050)
3.  **OCF**: Sun K, Jiang P, Chan KC, et al. Orientation-aware plasma cell-free DNA fragmentation analysis in open chromatin regions informs tissue of origin. *Genome Res*. 2019;29(3):418-427. [DOI](https://doi.org/10.1101/gr.242719.118)
4.  **UXM**: Sun K, et al. Fragment-level methylation measures cell-of-origin and cancer-specific signals in cell-free DNA. *Nature*. 2023;616(7956):563-571. [DOI](https://doi.org/10.1038/s41586-022-05580-6)

## Acknowledgements
Krewlyzer was developed by the **MSK-ACCESS** team at Memorial Sloan Kettering Cancer Center.
